from sedaro_base_client.paths.models_branches_branch_id_thermal_temp_controllers_states_block_id.delete import ApiFordelete
from sedaro_base_client.paths.models_branches_branch_id_thermal_temp_controllers_states_block_id.patch import ApiForpatch


class ModelsBranchesBranchIdThermalTempControllersStatesBlockId(
    ApiFordelete,
    ApiForpatch,
):
    pass
