from sedaro_base_client.paths.models_branches_branch_id_thermal_temp_controllers_coolers_.post import ApiForpost


class ModelsBranchesBranchIdThermalTempControllersCoolers(
    ApiForpost,
):
    pass
