from sedaro_base_client.paths.models_branches_branch_id_gnc_reference_vectors_target_group_vectors_block_id.delete import ApiFordelete
from sedaro_base_client.paths.models_branches_branch_id_gnc_reference_vectors_target_group_vectors_block_id.patch import ApiForpatch


class ModelsBranchesBranchIdGncReferenceVectorsTargetGroupVectorsBlockId(
    ApiFordelete,
    ApiForpatch,
):
    pass
